@@ -4,18 +4,19 @@ using System.Diagnostics;
 using System.Text;
 using System.Text.RegularExpressions;
 using System.Threading;
-
-using Avalonia.Threading;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
     public partial class Command
     {
-        public class ReadToEndResult
+        public class Result
         {
             public bool IsSuccess { get; set; } = false;
-            public string StdOut { get; set; } = "";
-            public string StdErr { get; set; } = "";
+            public string StdOut { get; set; } = string.Empty;
+            public string StdErr { get; set; } = string.Empty;
+
+            public static Result Failed(string reason) => new Result() { StdErr = reason };
         }
 
         public enum EditorType
@@ -26,32 +27,47 @@ namespace SourceGit.Commands
         }
 
         public string Context { get; set; } = string.Empty;
-        public CancellationToken CancellationToken { get; set; } = CancellationToken.None;
         public string WorkingDirectory { get; set; } = null;
-        public EditorType Editor { get; set; } = EditorType.CoreEditor; // Only used in Exec() mode
+        public EditorType Editor { get; set; } = EditorType.CoreEditor;
         public string SSHKey { get; set; } = string.Empty;
         public string Args { get; set; } = string.Empty;
+
+        // Only used in `ExecAsync` mode.
+        public CancellationToken CancellationToken { get; set; } = CancellationToken.None;
         public bool RaiseError { get; set; } = true;
         public Models.ICommandLog Log { get; set; } = null;
 
-        public bool Exec()
+        public void Exec()
+        {
+            try
+            {
+                var start = CreateGitStartInfo(false);
+                Process.Start(start);
+            }
+            catch (Exception ex)
+            {
+                App.RaiseException(Context, ex.Message);
+            }
+        }
+
+        public async Task<bool> ExecAsync()
         {
             Log?.AppendLine($"$ git {Args}\n");
 
-            var start = CreateGitStartInfo();
             var errs = new List<string>();
-            var proc = new Process() { StartInfo = start };
 
+            using var proc = new Process();
+            proc.StartInfo = CreateGitStartInfo(true);
             proc.OutputDataReceived += (_, e) => HandleOutput(e.Data, errs);
             proc.ErrorDataReceived += (_, e) => HandleOutput(e.Data, errs);
 
-            var dummy = null as Process;
+            Process dummy = null;
             var dummyProcLock = new object();
             try
             {
                 proc.Start();
 
-                // It not safe, please only use `CancellationToken` in readonly commands.
+                // Not safe, please only use `CancellationToken` in readonly commands.
                 if (CancellationToken.CanBeCanceled)
                 {
                     dummy = proc;
@@ -68,7 +84,7 @@ namespace SourceGit.Commands
             catch (Exception e)
             {
                 if (RaiseError)
-                    Dispatcher.UIThread.Post(() => App.RaiseException(Context, e.Message));
+                    App.RaiseException(Context, e.Message);
 
                 Log?.AppendLine(string.Empty);
                 return false;
@@ -76,7 +92,15 @@ namespace SourceGit.Commands
 
             proc.BeginOutputReadLine();
             proc.BeginErrorReadLine();
-            proc.WaitForExit();
+
+            try
+            {
+                await proc.WaitForExitAsync(CancellationToken).ConfigureAwait(false);
+            }
+            catch (Exception e)
+            {
+                HandleOutput(e.Message, errs);
+            }
 
             if (dummy != null)
             {
@@ -86,17 +110,15 @@ namespace SourceGit.Commands
                 }
             }
 
-            int exitCode = proc.ExitCode;
-            proc.Close();
             Log?.AppendLine(string.Empty);
 
-            if (!CancellationToken.IsCancellationRequested && exitCode != 0)
+            if (!CancellationToken.IsCancellationRequested && proc.ExitCode != 0)
             {
                 if (RaiseError)
                 {
                     var errMsg = string.Join("\n", errs).Trim();
                     if (!string.IsNullOrEmpty(errMsg))
-                        Dispatcher.UIThread.Post(() => App.RaiseException(Context, errMsg));
+                        App.RaiseException(Context, errMsg);
                 }
 
                 return false;
@@ -105,10 +127,9 @@ namespace SourceGit.Commands
             return true;
         }
 
-        public ReadToEndResult ReadToEnd()
+        protected async Task<Result> ReadToEndAsync()
         {
-            var start = CreateGitStartInfo();
-            var proc = new Process() { StartInfo = start };
+            using var proc = new Process() { StartInfo = CreateGitStartInfo(true) };
 
             try
             {
@@ -116,50 +137,42 @@ namespace SourceGit.Commands
             }
             catch (Exception e)
             {
-                return new ReadToEndResult()
-                {
-                    IsSuccess = false,
-                    StdOut = string.Empty,
-                    StdErr = e.Message,
-                };
+                return Result.Failed(e.Message);
             }
 
-            var rs = new ReadToEndResult()
-            {
-                StdOut = proc.StandardOutput.ReadToEnd(),
-                StdErr = proc.StandardError.ReadToEnd(),
-            };
+            var rs = new Result() { IsSuccess = true };
+            rs.StdOut = await proc.StandardOutput.ReadToEndAsync(CancellationToken).ConfigureAwait(false);
+            rs.StdErr = await proc.StandardError.ReadToEndAsync(CancellationToken).ConfigureAwait(false);
+            await proc.WaitForExitAsync(CancellationToken).ConfigureAwait(false);
 
-            proc.WaitForExit();
             rs.IsSuccess = proc.ExitCode == 0;
-            proc.Close();
-
             return rs;
         }
 
-        private ProcessStartInfo CreateGitStartInfo()
+        private ProcessStartInfo CreateGitStartInfo(bool redirect)
         {
             var start = new ProcessStartInfo();
             start.FileName = Native.OS.GitExecutable;
-            start.Arguments = "--no-pager -c core.quotepath=off -c credential.helper=manager ";
             start.UseShellExecute = false;
             start.CreateNoWindow = true;
-            start.RedirectStandardOutput = true;
-            start.RedirectStandardError = true;
-            start.StandardOutputEncoding = Encoding.UTF8;
-            start.StandardErrorEncoding = Encoding.UTF8;
+
+            if (redirect)
+            {
+                start.RedirectStandardOutput = true;
+                start.RedirectStandardError = true;
+                start.StandardOutputEncoding = Encoding.UTF8;
+                start.StandardErrorEncoding = Encoding.UTF8;
+            }
 
             // Force using this app as SSH askpass program
             var selfExecFile = Process.GetCurrentProcess().MainModule!.FileName;
-            if (!OperatingSystem.IsLinux())
-                start.Environment.Add("DISPLAY", "required");
             start.Environment.Add("SSH_ASKPASS", selfExecFile); // Can not use parameter here, because it invoked by SSH with `exec`
-            start.Environment.Add("SSH_ASKPASS_REQUIRE", "prefer");
+            start.Environment.Add("SSH_ASKPASS_REQUIRE", "force");
             start.Environment.Add("SOURCEGIT_LAUNCH_AS_ASKPASS", "TRUE");
 
             // If an SSH private key was provided, sets the environment.
             if (!start.Environment.ContainsKey("GIT_SSH_COMMAND") && !string.IsNullOrEmpty(SSHKey))
-                start.Environment.Add("GIT_SSH_COMMAND", $"ssh -i '{SSHKey}'");
+                start.Environment.Add("GIT_SSH_COMMAND", $"ssh -o AddKeysToAgent=yes -i {SSHKey.Quoted()}");
 
             // Force using en_US.UTF-8 locale
             if (OperatingSystem.IsLinux())
@@ -168,16 +181,27 @@ namespace SourceGit.Commands
                 start.Environment.Add("LC_ALL", "C");
             }
 
-            // Force using this app as git editor.
-            start.Arguments += Editor switch
-            {
-                EditorType.CoreEditor => $"-c core.editor=\"\\\"{selfExecFile}\\\" --core-editor\" ",
-                EditorType.RebaseEditor => $"-c core.editor=\"\\\"{selfExecFile}\\\" --rebase-message-editor\" -c sequence.editor=\"\\\"{selfExecFile}\\\" --rebase-todo-editor\" -c rebase.abbreviateCommands=true ",
-                _ => "-c core.editor=true ",
-            };
+            var builder = new StringBuilder();
+            builder
+                .Append("--no-pager -c core.quotepath=off -c credential.helper=")
+                .Append(Native.OS.CredentialHelper)
+                .Append(' ');
 
-            // Append command args
-            start.Arguments += Args;
+            switch (Editor)
+            {
+                case EditorType.CoreEditor:
+                    builder.Append($"""-c core.editor="\"{selfExecFile}\" --core-editor" """);
+                    break;
+                case EditorType.RebaseEditor:
+                    builder.Append($"""-c core.editor="\"{selfExecFile}\" --rebase-message-editor" -c sequence.editor="\"{selfExecFile}\" --rebase-todo-editor" -c rebase.abbreviateCommands=true """);
+                    break;
+                default:
+                    builder.Append("-c core.editor=true ");
+                    break;
+            }
+
+            builder.Append(Args);
+            start.Arguments = builder.ToString();
 
             // Working directory
             if (!string.IsNullOrEmpty(WorkingDirectory))
@@ -188,7 +212,9 @@ namespace SourceGit.Commands
 
         private void HandleOutput(string line, List<string> errs)
         {
-            line ??= string.Empty;
+            if (line == null)
+                return;
+
             Log?.AppendLine(line);
 
             // Lines to hide in error message.
