@@ -1,4 +1,5 @@
 ﻿using System.IO;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
@@ -7,33 +8,33 @@ namespace SourceGit.Commands
         public Commit(string repo, string message, bool signOff, bool amend, bool resetAuthor)
         {
             _tmpFile = Path.GetTempFileName();
-            File.WriteAllText(_tmpFile, message);
+            _message = message;
 
             WorkingDirectory = repo;
             Context = repo;
-            Args = $"commit --allow-empty --file=\"{_tmpFile}\"";
+            Args = $"commit --allow-empty --file={_tmpFile.Quoted()}";
             if (signOff)
                 Args += " --signoff";
             if (amend)
                 Args += resetAuthor ? " --amend --reset-author --no-edit" : " --amend --no-edit";
         }
 
-        public bool Run()
+        public async Task<bool> RunAsync()
         {
-            var succ = Exec();
-
             try
             {
+                await File.WriteAllTextAsync(_tmpFile, _message).ConfigureAwait(false);
+                var succ = await ExecAsync().ConfigureAwait(false);
                 File.Delete(_tmpFile);
+                return succ;
             }
             catch
             {
-                // Ignore
+                return false;
             }
-
-            return succ;
         }
 
-        private readonly string _tmpFile;
+        private readonly string _tmpFile = string.Empty;
+        private readonly string _message = string.Empty;
     }
 }
