@@ -1,6 +1,8 @@
 using System;
 using System.Collections.Generic;
+using System.IO;
 using System.Text.RegularExpressions;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
@@ -35,23 +37,13 @@ namespace SourceGit.Commands
                 Args = $"diff --no-ext-diff --patch --unified={unified} {opt}";
         }
 
-        public Models.DiffResult Result()
+        public async Task<Models.DiffResult> ReadAsync()
         {
-            var rs = ReadToEnd();
-            var start = 0;
-            var end = rs.StdOut.IndexOf('\n', start);
-            while (end > 0)
-            {
-                var line = rs.StdOut.Substring(start, end - start);
+            var rs = await ReadToEndAsync().ConfigureAwait(false);
+            var sr = new StringReader(rs.StdOut);
+            while (sr.ReadLine() is { } line)
                 ParseLine(line);
 
-                start = end + 1;
-                end = rs.StdOut.IndexOf('\n', start);
-            }
-
-            if (start < rs.StdOut.Length)
-                ParseLine(rs.StdOut.Substring(start));
-
             if (_result.IsBinary || _result.IsLFS || _result.TextDiff.Lines.Count == 0)
             {
                 _result.TextDiff = null;
@@ -248,14 +240,10 @@ namespace SourceGit.Commands
                         foreach (var chunk in chunks)
                         {
                             if (chunk.DeletedCount > 0)
-                            {
                                 left.Highlights.Add(new Models.TextInlineRange(chunk.DeletedStart, chunk.DeletedCount));
-                            }
 
                             if (chunk.AddedCount > 0)
-                            {
                                 right.Highlights.Add(new Models.TextInlineRange(chunk.AddedStart, chunk.AddedCount));
-                            }
                         }
                     }
                 }
