@@ -1,12 +1,15 @@
-﻿namespace SourceGit.Commands
+﻿using System.Threading.Tasks;
+
+namespace SourceGit.Commands
 {
     public class Fetch : Command
     {
         public Fetch(string repo, string remote, bool noTags, bool force)
         {
+            _remoteKey = $"remote.{remote}.sshkey";
+
             WorkingDirectory = repo;
             Context = repo;
-            SSHKey = new Config(repo).Get($"remote.{remote}.sshkey");
             Args = "fetch --progress --verbose ";
 
             if (noTags)
@@ -18,14 +21,24 @@
                 Args += "--force ";
 
             Args += remote;
+
         }
 
         public Fetch(string repo, Models.Branch local, Models.Branch remote)
         {
+            _remoteKey = $"remote.{remote.Remote}.sshkey";
+
             WorkingDirectory = repo;
             Context = repo;
-            SSHKey = new Config(repo).Get($"remote.{remote.Remote}.sshkey");
             Args = $"fetch --progress --verbose {remote.Remote} {remote.Name}:{local.Name}";
         }
+
+        public async Task<bool> RunAsync()
+        {
+            SSHKey = await new Config(WorkingDirectory).GetAsync(_remoteKey).ConfigureAwait(false);
+            return await ExecAsync().ConfigureAwait(false);
+        }
+
+        private readonly string _remoteKey;
     }
 }
