@@ -1,17 +1,18 @@
 ﻿using System;
 using System.Diagnostics;
 using System.IO;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
     public static class QueryFileContent
     {
-        public static Stream Run(string repo, string revision, string file)
+        public static async Task<Stream> RunAsync(string repo, string revision, string file)
         {
             var starter = new ProcessStartInfo();
             starter.WorkingDirectory = repo;
             starter.FileName = Native.OS.GitExecutable;
-            starter.Arguments = $"show {revision}:\"{file}\"";
+            starter.Arguments = $"show {revision}:{file.Quoted()}";
             starter.UseShellExecute = false;
             starter.CreateNoWindow = true;
             starter.WindowStyle = ProcessWindowStyle.Hidden;
@@ -20,23 +21,20 @@ namespace SourceGit.Commands
             var stream = new MemoryStream();
             try
             {
-                var proc = new Process() { StartInfo = starter };
-                proc.Start();
-                proc.StandardOutput.BaseStream.CopyTo(stream);
-                proc.WaitForExit();
-                proc.Close();
-
-                stream.Position = 0;
+                using var proc = Process.Start(starter);
+                await proc.StandardOutput.BaseStream.CopyToAsync(stream).ConfigureAwait(false);
+                await proc.WaitForExitAsync().ConfigureAwait(false);
             }
             catch (Exception e)
             {
                 App.RaiseException(repo, $"Failed to query file content: {e}");
             }
 
+            stream.Position = 0;
             return stream;
         }
 
-        public static Stream FromLFS(string repo, string oid, long size)
+        public static async Task<Stream> FromLFSAsync(string repo, string oid, long size)
         {
             var starter = new ProcessStartInfo();
             starter.WorkingDirectory = repo;
@@ -51,22 +49,19 @@ namespace SourceGit.Commands
             var stream = new MemoryStream();
             try
             {
-                var proc = new Process() { StartInfo = starter };
-                proc.Start();
-                proc.StandardInput.WriteLine("version https://git-lfs.github.com/spec/v1");
-                proc.StandardInput.WriteLine($"oid sha256:{oid}");
-                proc.StandardInput.WriteLine($"size {size}");
-                proc.StandardOutput.BaseStream.CopyTo(stream);
-                proc.WaitForExit();
-                proc.Close();
-
-                stream.Position = 0;
+                using var proc = Process.Start(starter);
+                await proc.StandardInput.WriteLineAsync("version https://git-lfs.github.com/spec/v1").ConfigureAwait(false);
+                await proc.StandardInput.WriteLineAsync($"oid sha256:{oid}").ConfigureAwait(false);
+                await proc.StandardInput.WriteLineAsync($"size {size}").ConfigureAwait(false);
+                await proc.StandardOutput.BaseStream.CopyToAsync(stream).ConfigureAwait(false);
+                await proc.WaitForExitAsync().ConfigureAwait(false);
             }
             catch (Exception e)
             {
                 App.RaiseException(repo, $"Failed to query file content: {e}");
             }
 
+            stream.Position = 0;
             return stream;
         }
     }
