@@ -1,4 +1,6 @@
-﻿namespace SourceGit.Commands
+﻿using System.Threading.Tasks;
+
+namespace SourceGit.Commands
 {
     public class QueryRepositoryRootPath : Command
     {
@@ -7,5 +9,10 @@
             WorkingDirectory = path;
             Args = "rev-parse --show-toplevel";
         }
+
+        public async Task<Result> GetResultAsync()
+        {
+            return await ReadToEndAsync().ConfigureAwait(false);
+        }
     }
 }
