@@ -1,5 +1,7 @@
 ﻿using System.Collections.Generic;
+using System.IO;
 using System.Text.RegularExpressions;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
@@ -12,35 +14,27 @@ namespace SourceGit.Commands
         {
             WorkingDirectory = repo;
             Context = repo;
-            Args = $"ls-tree -z {sha}";
+            Args = $"ls-tree {sha}";
 
             if (!string.IsNullOrEmpty(parentFolder))
-                Args += $" -- \"{parentFolder}\"";
+                Args += $" -- {parentFolder.Quoted()}";
         }
 
-        public List<Models.Object> Result()
+        public async Task<List<Models.Object>> GetResultAsync()
         {
-            var rs = ReadToEnd();
+            var outs = new List<Models.Object>();
+            var rs = await ReadToEndAsync().ConfigureAwait(false);
             if (rs.IsSuccess)
             {
-                var start = 0;
-                var end = rs.StdOut.IndexOf('\0', start);
-                while (end > 0)
-                {
-                    var line = rs.StdOut.Substring(start, end - start);
-                    Parse(line);
-                    start = end + 1;
-                    end = rs.StdOut.IndexOf('\0', start);
-                }
-
-                if (start < rs.StdOut.Length)
-                    Parse(rs.StdOut.Substring(start));
+                var sr = new StringReader(rs.StdOut);
+                while (sr.ReadLine() is { } line)
+                    Parse(outs, line);
             }
 
-            return _objects;
+            return outs;
         }
 
-        private void Parse(string line)
+        private void Parse(List<Models.Object> outs, string line)
         {
             var match = REG_FORMAT().Match(line);
             if (!match.Success)
@@ -60,9 +54,7 @@ namespace SourceGit.Commands
                 _ => obj.Type,
             };
 
-            _objects.Add(obj);
+            outs.Add(obj);
         }
-
-        private List<Models.Object> _objects = new List<Models.Object>();
     }
 }
