@@ -2,8 +2,7 @@
 using System.Collections.Generic;
 using System.Diagnostics;
 using System.Text;
-
-using Avalonia.Threading;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
@@ -45,11 +44,11 @@ namespace SourceGit.Commands
                     _patchBuilder.Append(c.Path);
                 }
 
-                _patchBuilder.Append("\n");
+                _patchBuilder.Append('\n');
             }
         }
 
-        public bool Exec()
+        public async Task<bool> ExecAsync()
         {
             var starter = new ProcessStartInfo();
             starter.WorkingDirectory = _repo;
@@ -64,27 +63,22 @@ namespace SourceGit.Commands
 
             try
             {
-                var proc = new Process() { StartInfo = starter };
-                proc.Start();
-                proc.StandardInput.Write(_patchBuilder.ToString());
+                using var proc = Process.Start(starter);
+                await proc.StandardInput.WriteAsync(_patchBuilder.ToString());
                 proc.StandardInput.Close();
 
-                var err = proc.StandardError.ReadToEnd();
-                proc.WaitForExit();
+                var err = await proc.StandardError.ReadToEndAsync().ConfigureAwait(false);
+                await proc.WaitForExitAsync().ConfigureAwait(false);
                 var rs = proc.ExitCode == 0;
-                proc.Close();
 
                 if (!rs)
-                    Dispatcher.UIThread.Invoke(() => App.RaiseException(_repo, err));
+                    App.RaiseException(_repo, err);
 
                 return rs;
             }
             catch (Exception e)
             {
-                Dispatcher.UIThread.Invoke(() =>
-                {
-                    App.RaiseException(_repo, "Failed to unstage changes: " + e.Message);
-                });
+                App.RaiseException(_repo, "Failed to unstage changes: " + e.Message);
                 return false;
             }
         }
