@@ -88,9 +88,7 @@ namespace SourceGit.Models
         {
             var c = Peek();
             if (c is not null)
-            {
                 _pos++;
-            }
             return c;
         }
 
@@ -129,7 +127,7 @@ namespace SourceGit.Models
                 {
                     case ESCAPE:
                         // allow to escape only \ and $
-                        if (Peek() is { } nc && (nc == ESCAPE || nc == VARIABLE_ANCHOR))
+                        if (Peek() is ESCAPE or VARIABLE_ANCHOR)
                         {
                             esc = true;
                             FlushText(tok, _pos - 1);
@@ -172,18 +170,18 @@ namespace SourceGit.Models
         {
             if (Next() != VARIABLE_START)
                 return null;
-            int name_start = _pos;
+            var nameStart = _pos;
             while (Next() is { } c)
             {
                 // name character, continue advancing
                 if (IsNameChar(c))
                     continue;
 
-                var name_end = _pos - 1;
+                var nameEnd = _pos - 1;
                 // not a name character but name is empty, cancel
-                if (name_start >= name_end)
+                if (nameStart >= nameEnd)
                     return null;
-                var name = new string(_chars, name_start, name_end - name_start);
+                var name = new string(_chars, nameStart, nameEnd - nameStart);
 
                 return c switch
                 {
@@ -320,9 +318,7 @@ namespace SourceGit.Models
         private static string EvalVariable(Context context, string name)
         {
             if (!s_variables.TryGetValue(name, out var getter))
-            {
                 return string.Empty;
-            }
             return getter(context);
         }
 
@@ -334,9 +330,7 @@ namespace SourceGit.Models
         private static string EvalVariable(Context context, SlicedVariable variable)
         {
             if (!s_slicedVariables.TryGetValue(variable.name, out var getter))
-            {
                 return string.Empty;
-            }
             return getter(context, variable.count);
         }
 
