@@ -16,7 +16,7 @@ namespace SourceGit.ViewModels
             Submodule = submodule;
         }
 
-        public override Task<bool> Sure()
+        public override async Task<bool> Sure()
         {
             _repo.SetWatcherEnabled(false);
             ProgressDescription = "Deleting submodule ...";
@@ -24,13 +24,13 @@ namespace SourceGit.ViewModels
             var log = _repo.CreateLog("Delete Submodule");
             Use(log);
 
-            return Task.Run(() =>
-            {
-                var succ = new Commands.Submodule(_repo.FullPath).Use(log).Delete(Submodule);
-                log.Complete();
-                CallUIThread(() => _repo.SetWatcherEnabled(true));
-                return succ;
-            });
+            var succ = await new Commands.Submodule(_repo.FullPath)
+                .Use(log)
+                .DeleteAsync(Submodule);
+
+            log.Complete();
+            _repo.SetWatcherEnabled(true);
+            return succ;
         }
 
         private readonly Repository _repo = null;
