@@ -49,7 +49,7 @@ namespace SourceGit.ViewModels
             return ValidationResult.Success;
         }
 
-        public override Task<bool> Sure()
+        public override async Task<bool> Sure()
         {
             _repo.SetWatcherEnabled(false);
             ProgressDescription = $"Git Flow - Start {Prefix}{_name} ...";
@@ -57,13 +57,10 @@ namespace SourceGit.ViewModels
             var log = _repo.CreateLog("GitFlow - Start");
             Use(log);
 
-            return Task.Run(() =>
-            {
-                var succ = Commands.GitFlow.Start(_repo.FullPath, Type, _name, log);
-                log.Complete();
-                CallUIThread(() => _repo.SetWatcherEnabled(true));
-                return succ;
-            });
+            var succ = await Commands.GitFlow.StartAsync(_repo.FullPath, Type, _name, log);
+            log.Complete();
+            _repo.SetWatcherEnabled(true);
+            return succ;
         }
 
         private readonly Repository _repo;
