@@ -1,4 +1,5 @@
 ﻿using System.IO;
+using System.Threading.Tasks;
 
 namespace SourceGit.ViewModels
 {
@@ -10,27 +11,27 @@ namespace SourceGit.ViewModels
             _cmd = cmd;
         }
 
-        public bool Abort()
+        public Task<bool> AbortAsync()
         {
             return new Commands.Command()
             {
                 WorkingDirectory = _repo,
                 Context = _repo,
                 Args = $"{_cmd} --abort",
-            }.Exec();
+            }.ExecAsync();
         }
 
-        public virtual bool Skip()
+        public virtual Task<bool> SkipAsync()
         {
             return new Commands.Command()
             {
                 WorkingDirectory = _repo,
                 Context = _repo,
                 Args = $"{_cmd} --skip",
-            }.Exec();
+            }.ExecAsync();
         }
 
-        public virtual bool Continue()
+        public virtual Task<bool> ContinueAsync()
         {
             return new Commands.Command()
             {
@@ -38,20 +39,7 @@ namespace SourceGit.ViewModels
                 Context = _repo,
                 Editor = Commands.Command.EditorType.None,
                 Args = $"{_cmd} --continue",
-            }.Exec();
-        }
-
-        protected string GetFriendlyNameOfCommit(Models.Commit commit)
-        {
-            var branchDecorator = commit.Decorators.Find(x => x.Type == Models.DecoratorType.LocalBranchHead || x.Type == Models.DecoratorType.RemoteBranchHead);
-            if (branchDecorator != null)
-                return branchDecorator.Name;
-
-            var tagDecorator = commit.Decorators.Find(x => x.Type == Models.DecoratorType.Tag);
-            if (tagDecorator != null)
-                return tagDecorator.Name;
-
-            return commit.SHA.Substring(0, 10);
+            }.ExecAsync();
         }
 
         protected string _repo = string.Empty;
@@ -63,18 +51,18 @@ namespace SourceGit.ViewModels
         public Models.Commit Head
         {
             get;
-            private set;
         }
 
         public string HeadName
         {
-            get => GetFriendlyNameOfCommit(Head);
+            get;
         }
 
         public CherryPickInProgress(Repository repo) : base(repo.FullPath, "cherry-pick")
         {
             var headSHA = File.ReadAllText(Path.Combine(repo.GitDir, "CHERRY_PICK_HEAD")).Trim();
-            Head = new Commands.QuerySingleCommit(repo.FullPath, headSHA).Result() ?? new Models.Commit() { SHA = headSHA };
+            Head = new Commands.QuerySingleCommit(repo.FullPath, headSHA).GetResultAsync().Result ?? new Models.Commit() { SHA = headSHA };
+            HeadName = Head.GetFriendlyName();
         }
     }
 
@@ -83,24 +71,21 @@ namespace SourceGit.ViewModels
         public string HeadName
         {
             get;
-            private set;
         }
 
         public string BaseName
         {
-            get => GetFriendlyNameOfCommit(Onto);
+            get;
         }
 
         public Models.Commit StoppedAt
         {
             get;
-            private set;
         }
 
         public Models.Commit Onto
         {
             get;
-            private set;
         }
 
         public RebaseInProgress(Repository repo) : base(repo.FullPath, "rebase")
@@ -114,16 +99,17 @@ namespace SourceGit.ViewModels
             var stoppedSHAPath = Path.Combine(repo.GitDir, "rebase-merge", "stopped-sha");
             var stoppedSHA = File.Exists(stoppedSHAPath)
                 ? File.ReadAllText(stoppedSHAPath).Trim()
-                : new Commands.QueryRevisionByRefName(repo.FullPath, HeadName).Result();
+                : new Commands.QueryRevisionByRefName(repo.FullPath, HeadName).GetResultAsync().Result;
 
             if (!string.IsNullOrEmpty(stoppedSHA))
-                StoppedAt = new Commands.QuerySingleCommit(repo.FullPath, stoppedSHA).Result() ?? new Models.Commit() { SHA = stoppedSHA };
+                StoppedAt = new Commands.QuerySingleCommit(repo.FullPath, stoppedSHA).GetResultAsync().Result ?? new Models.Commit() { SHA = stoppedSHA };
 
             var ontoSHA = File.ReadAllText(Path.Combine(repo.GitDir, "rebase-merge", "onto")).Trim();
-            Onto = new Commands.QuerySingleCommit(repo.FullPath, ontoSHA).Result() ?? new Models.Commit() { SHA = ontoSHA };
+            Onto = new Commands.QuerySingleCommit(repo.FullPath, ontoSHA).GetResultAsync().Result ?? new Models.Commit() { SHA = ontoSHA };
+            BaseName = Onto.GetFriendlyName();
         }
 
-        public override bool Continue()
+        public override Task<bool> ContinueAsync()
         {
             return new Commands.Command()
             {
@@ -131,7 +117,7 @@ namespace SourceGit.ViewModels
                 Context = _repo,
                 Editor = Commands.Command.EditorType.RebaseEditor,
                 Args = "rebase --continue",
-            }.Exec();
+            }.ExecAsync();
         }
     }
 
@@ -140,13 +126,12 @@ namespace SourceGit.ViewModels
         public Models.Commit Head
         {
             get;
-            private set;
         }
 
         public RevertInProgress(Repository repo) : base(repo.FullPath, "revert")
         {
             var headSHA = File.ReadAllText(Path.Combine(repo.GitDir, "REVERT_HEAD")).Trim();
-            Head = new Commands.QuerySingleCommit(repo.FullPath, headSHA).Result() ?? new Models.Commit() { SHA = headSHA };
+            Head = new Commands.QuerySingleCommit(repo.FullPath, headSHA).GetResultAsync().Result ?? new Models.Commit() { SHA = headSHA };
         }
     }
 
@@ -155,31 +140,30 @@ namespace SourceGit.ViewModels
         public string Current
         {
             get;
-            private set;
         }
 
         public Models.Commit Source
         {
             get;
-            private set;
         }
 
         public string SourceName
         {
-            get => GetFriendlyNameOfCommit(Source);
+            get;
         }
 
         public MergeInProgress(Repository repo) : base(repo.FullPath, "merge")
         {
-            Current = Commands.Branch.ShowCurrent(repo.FullPath);
+            Current = new Commands.QueryCurrentBranch(repo.FullPath).GetResultAsync().Result;
 
             var sourceSHA = File.ReadAllText(Path.Combine(repo.GitDir, "MERGE_HEAD")).Trim();
-            Source = new Commands.QuerySingleCommit(repo.FullPath, sourceSHA).Result() ?? new Models.Commit() { SHA = sourceSHA };
+            Source = new Commands.QuerySingleCommit(repo.FullPath, sourceSHA).GetResultAsync().Result ?? new Models.Commit() { SHA = sourceSHA };
+            SourceName = Source.GetFriendlyName();
         }
 
-        public override bool Skip()
+        public override Task<bool> SkipAsync()
         {
-            return true;
+            return Task.FromResult(true);
         }
     }
 }
