@@ -11,6 +11,12 @@ using CommunityToolkit.Mvvm.ComponentModel;
 
 namespace SourceGit.ViewModels
 {
+    public record InteractiveRebasePrefill(string sha, Models.InteractiveRebaseAction action)
+    {
+        public string SHA { get; } = sha;
+        public Models.InteractiveRebaseAction Action { get; } = action;
+    }
+
     public class InteractiveRebaseItem : ObservableObject
     {
         public Models.Commit Commit
@@ -52,11 +58,8 @@ namespace SourceGit.ViewModels
                 if (SetProperty(ref _fullMessage, value))
                 {
                     var normalized = value.ReplaceLineEndings("\n");
-                    var idx = normalized.IndexOf("\n\n", StringComparison.Ordinal);
-                    if (idx > 0)
-                        Subject = normalized.Substring(0, idx).ReplaceLineEndings(" ");
-                    else
-                        Subject = value.ReplaceLineEndings(" ");
+                    var parts = normalized.Split("\n\n", 2);
+                    Subject = parts[0].ReplaceLineEndings(" ");
                 }
             }
         }
@@ -88,9 +91,15 @@ namespace SourceGit.ViewModels
             private set;
         }
 
-        public AvaloniaList<Models.IssueTrackerRule> IssueTrackerRules
+        public bool AutoStash
         {
-            get => _repo.Settings.IssueTrackerRules;
+            get;
+            set;
+        } = true;
+
+        public AvaloniaList<Models.IssueTracker> IssueTrackers
+        {
+            get => _repo.IssueTrackers;
         }
 
         public bool IsLoading
@@ -121,30 +130,42 @@ namespace SourceGit.ViewModels
             private set;
         }
 
-        public InteractiveRebase(Repository repo, Models.Branch current, Models.Commit on)
+        public InteractiveRebase(Repository repo, Models.Commit on, InteractiveRebasePrefill prefill = null)
         {
-            var repoPath = repo.FullPath;
             _repo = repo;
-
-            Current = current;
+            Current = repo.CurrentBranch;
             On = on;
             IsLoading = true;
-            DetailContext = new CommitDetail(repo);
+            DetailContext = new CommitDetail(repo, false);
 
-            Task.Run(() =>
+            Task.Run(async () =>
             {
-                var commits = new Commands.QueryCommitsForInteractiveRebase(repoPath, on.SHA).Result();
-                var list = new List<InteractiveRebaseItem>();
+                var commits = await new Commands.QueryCommitsForInteractiveRebase(_repo.FullPath, on.SHA)
+                    .GetResultAsync()
+                    .ConfigureAwait(false);
 
+                var list = new List<InteractiveRebaseItem>();
                 for (var i = 0; i < commits.Count; i++)
                 {
                     var c = commits[i];
                     list.Add(new InteractiveRebaseItem(c.Commit, c.Message, i < commits.Count - 1));
                 }
 
-                Dispatcher.UIThread.Invoke(() =>
+                InteractiveRebaseItem selected = list.Count > 0 ? list[0] : null;
+                if (prefill != null)
+                {
+                    var item = list.Find(x => x.Commit.SHA.Equals(prefill.SHA, StringComparison.Ordinal));
+                    if (item != null)
+                    {
+                        item.Action = prefill.Action;
+                        selected = item;
+                    }
+                }
+
+                Dispatcher.UIThread.Post(() =>
                 {
                     Items.AddRange(list);
+                    SelectedItem = selected;
                     IsLoading = false;
                 });
             });
@@ -188,11 +209,11 @@ namespace SourceGit.ViewModels
             UpdateItems();
         }
 
-        public Task<bool> Start()
+        public async Task<bool> Start()
         {
             _repo.SetWatcherEnabled(false);
 
-            var saveFile = Path.Combine(_repo.GitDir, "sourcegit_rebase_jobs.json");
+            var saveFile = Path.Combine(_repo.GitDir, "sourcegit.interactive_rebase");
             var collection = new Models.InteractiveRebaseJobCollection();
             collection.OrigHead = _repo.CurrentBranch.Head;
             collection.Onto = On.SHA;
@@ -206,16 +227,19 @@ namespace SourceGit.ViewModels
                     Message = item.FullMessage,
                 });
             }
-            File.WriteAllText(saveFile, JsonSerializer.Serialize(collection, JsonCodeGen.Default.InteractiveRebaseJobCollection));
+            await using (var stream = File.Create(saveFile))
+            {
+                await JsonSerializer.SerializeAsync(stream, collection, JsonCodeGen.Default.InteractiveRebaseJobCollection);
+            }
 
             var log = _repo.CreateLog("Interactive Rebase");
-            return Task.Run(() =>
-            {
-                var succ = new Commands.InteractiveRebase(_repo.FullPath, On.SHA).Use(log).Exec();
-                log.Complete();
-                Dispatcher.UIThread.Invoke(() => _repo.SetWatcherEnabled(true));
-                return succ;
-            });
+            var succ = await new Commands.InteractiveRebase(_repo.FullPath, On.SHA, AutoStash)
+                .Use(log)
+                .ExecAsync();
+
+            log.Complete();
+            _repo.SetWatcherEnabled(true);
+            return succ;
         }
 
         private void UpdateItems()
