@@ -19,7 +19,7 @@ namespace SourceGit.ViewModels
             SelectedRemote = _repo.Remotes[0];
         }
 
-        public override Task<bool> Sure()
+        public override async Task<bool> Sure()
         {
             _repo.SetWatcherEnabled(false);
             ProgressDescription = "Fetching LFS objects from remote ...";
@@ -27,13 +27,13 @@ namespace SourceGit.ViewModels
             var log = _repo.CreateLog("LFS Fetch");
             Use(log);
 
-            return Task.Run(() =>
-            {
-                new Commands.LFS(_repo.FullPath).Fetch(SelectedRemote.Name, log);
-                log.Complete();
-                CallUIThread(() => _repo.SetWatcherEnabled(true));
-                return true;
-            });
+            await new Commands.LFS(_repo.FullPath)
+                .Use(log)
+                .FetchAsync(SelectedRemote.Name);
+
+            log.Complete();
+            _repo.SetWatcherEnabled(true);
+            return true;
         }
 
         private readonly Repository _repo = null;
