@@ -1,9 +1,5 @@
-﻿using System;
-using System.Diagnostics.CodeAnalysis;
+﻿using System.Diagnostics.CodeAnalysis;
 using System.Threading.Tasks;
-
-using Avalonia.Threading;
-
 using CommunityToolkit.Mvvm.ComponentModel;
 
 namespace SourceGit.ViewModels
@@ -41,11 +37,6 @@ namespace SourceGit.ViewModels
             return null;
         }
 
-        protected void CallUIThread(Action action)
-        {
-            Dispatcher.UIThread.Invoke(action);
-        }
-
         protected void Use(CommandLog log)
         {
             log.Register(SetDescription);
