@@ -285,6 +285,12 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _commitChangeViewMode, value);
         }
 
+        public Models.ChangeViewMode StashChangeViewMode
+        {
+            get => _stashChangeViewMode;
+            set => SetProperty(ref _stashChangeViewMode, value);
+        }
+
         public string GitInstallPath
         {
             get => Native.OS.GitExecutable;
@@ -304,6 +310,20 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _gitDefaultCloneDir, value);
         }
 
+        public bool UseLibsecretInsteadOfGCM
+        {
+            get => Native.OS.CredentialHelper.Equals("libsecret", StringComparison.Ordinal);
+            set
+            {
+                var helper = value ? "libsecret" : "manager";
+                if (OperatingSystem.IsLinux() && !Native.OS.CredentialHelper.Equals(helper, StringComparison.Ordinal))
+                {
+                    Native.OS.CredentialHelper = helper;
+                    OnPropertyChanged();
+                }
+            }
+        }
+
         public int ShellOrTerminal
         {
             get => _shellOrTerminal;
@@ -336,25 +356,34 @@ namespace SourceGit.ViewModels
 
         public int ExternalMergeToolType
         {
-            get => _externalMergeToolType;
+            get => Native.OS.ExternalMergerType;
             set
             {
-                var changed = SetProperty(ref _externalMergeToolType, value);
-                if (changed && !OperatingSystem.IsWindows() && value > 0 && value < Models.ExternalMerger.Supported.Count)
+                if (Native.OS.ExternalMergerType != value)
                 {
-                    var tool = Models.ExternalMerger.Supported[value];
-                    if (File.Exists(tool.Exec))
-                        ExternalMergeToolPath = tool.Exec;
-                    else
-                        ExternalMergeToolPath = string.Empty;
+                    Native.OS.ExternalMergerType = value;
+                    OnPropertyChanged();
+
+                    if (!_isLoading)
+                    {
+                        Native.OS.AutoSelectExternalMergeToolExecFile();
+                        OnPropertyChanged(nameof(ExternalMergeToolPath));
+                    }
                 }
             }
         }
 
         public string ExternalMergeToolPath
         {
-            get => _externalMergeToolPath;
-            set => SetProperty(ref _externalMergeToolPath, value);
+            get => Native.OS.ExternalMergerExecFile;
+            set
+            {
+                if (!Native.OS.ExternalMergerExecFile.Equals(value, StringComparison.Ordinal))
+                {
+                    Native.OS.ExternalMergerExecFile = value;
+                    OnPropertyChanged();
+                }
+            }
         }
 
         public uint StatisticsSampleColor
@@ -523,8 +552,8 @@ namespace SourceGit.ViewModels
                 return;
 
             var file = Path.Combine(Native.OS.DataDir, "preference.json");
-            var data = JsonSerializer.Serialize(this, JsonCodeGen.Default.Preferences);
-            File.WriteAllText(file, data);
+            using var stream = File.Create(file);
+            JsonSerializer.Serialize(stream, this, JsonCodeGen.Default.Preferences);
         }
 
         private static Preferences Load()
@@ -535,7 +564,8 @@ namespace SourceGit.ViewModels
 
             try
             {
-                return JsonSerializer.Deserialize(File.ReadAllText(path), JsonCodeGen.Default.Preferences);
+                using var stream = File.OpenRead(path);
+                return JsonSerializer.Deserialize(stream, JsonCodeGen.Default.Preferences);
             }
             catch
             {
@@ -584,13 +614,6 @@ namespace SourceGit.ViewModels
             }
         }
 
-        private void SortNodesRecursive(List<RepositoryNode> collection)
-        {
-            SortNodes(collection);
-            foreach (var node in collection)
-                SortNodesRecursive(node.SubNodes);
-        }
-
         private RepositoryNode FindNodeRecursive(string id, List<RepositoryNode> collection)
         {
             foreach (var node in collection)
@@ -699,13 +722,10 @@ namespace SourceGit.ViewModels
         private Models.ChangeViewMode _unstagedChangeViewMode = Models.ChangeViewMode.List;
         private Models.ChangeViewMode _stagedChangeViewMode = Models.ChangeViewMode.List;
         private Models.ChangeViewMode _commitChangeViewMode = Models.ChangeViewMode.List;
+        private Models.ChangeViewMode _stashChangeViewMode = Models.ChangeViewMode.List;
 
         private string _gitDefaultCloneDir = string.Empty;
-
         private int _shellOrTerminal = -1;
-        private int _externalMergeToolType = 0;
-        private string _externalMergeToolPath = string.Empty;
-
         private uint _statisticsSampleColor = 0xFF00FF00;
     }
 }
