@@ -1,4 +1,5 @@
-﻿using System.Threading.Tasks;
+﻿using System;
+using System.Threading.Tasks;
 
 namespace SourceGit.ViewModels
 {
@@ -28,30 +29,27 @@ namespace SourceGit.ViewModels
             Force = false;
         }
 
-        public override Task<bool> Sure()
+        public override async Task<bool> Sure()
         {
             _repo.SetWatcherEnabled(false);
-            ProgressDescription = $"Push {Revision.SHA.Substring(0, 10)} -> {RemoteBranch.FriendlyName} ...";
+            ProgressDescription = $"Push {Revision.SHA.AsSpan(0, 10)} -> {RemoteBranch.FriendlyName} ...";
 
             var log = _repo.CreateLog("Push Revision");
             Use(log);
 
-            return Task.Run(() =>
-            {
-                var succ = new Commands.Push(
-                    _repo.FullPath,
-                    Revision.SHA,
-                    RemoteBranch.Remote,
-                    RemoteBranch.Name,
-                    false,
-                    false,
-                    false,
-                    Force).Use(log).Exec();
+            var succ = await new Commands.Push(
+                _repo.FullPath,
+                Revision.SHA,
+                RemoteBranch.Remote,
+                RemoteBranch.Name,
+                false,
+                false,
+                false,
+                Force).Use(log).RunAsync();
 
-                log.Complete();
-                CallUIThread(() => _repo.SetWatcherEnabled(true));
-                return succ;
-            });
+            log.Complete();
+            _repo.SetWatcherEnabled(true);
+            return succ;
         }
 
         private readonly Repository _repo;
