@@ -34,7 +34,7 @@ namespace SourceGit.ViewModels
             SelectedRemote = _repo.Remotes[0];
         }
 
-        public override Task<bool> Sure()
+        public override async Task<bool> Sure()
         {
             _repo.SetWatcherEnabled(false);
             ProgressDescription = "Pushing tag ...";
@@ -42,28 +42,29 @@ namespace SourceGit.ViewModels
             var log = _repo.CreateLog("Push Tag");
             Use(log);
 
-            return Task.Run(() =>
+            var succ = true;
+            var tag = $"refs/tags/{Target.Name}";
+            if (_pushAllRemotes)
             {
-                var succ = true;
-                var tag = $"refs/tags/{Target.Name}";
-                if (_pushAllRemotes)
+                foreach (var remote in _repo.Remotes)
                 {
-                    foreach (var remote in _repo.Remotes)
-                    {
-                        succ = new Commands.Push(_repo.FullPath, remote.Name, tag, false).Use(log).Exec();
-                        if (!succ)
-                            break;
-                    }
-                }
-                else
-                {
-                    succ = new Commands.Push(_repo.FullPath, SelectedRemote.Name, tag, false).Use(log).Exec();
+                    succ = await new Commands.Push(_repo.FullPath, remote.Name, tag, false)
+                        .Use(log)
+                        .RunAsync();
+                    if (!succ)
+                        break;
                 }
+            }
+            else
+            {
+                succ = await new Commands.Push(_repo.FullPath, SelectedRemote.Name, tag, false)
+                    .Use(log)
+                    .RunAsync();
+            }
 
-                log.Complete();
-                CallUIThread(() => _repo.SetWatcherEnabled(true));
-                return succ;
-            });
+            log.Complete();
+            _repo.SetWatcherEnabled(true);
+            return succ;
         }
 
         private readonly Repository _repo = null;
