@@ -21,9 +21,9 @@ namespace SourceGit.ViewModels
         {
             LFS = new Models.RevisionLFSObject() { Object = lfs };
 
-            Task.Run(() =>
+            Task.Run(async () =>
             {
-                var source = ImageSource.FromLFSObject(repo, lfs, decoder);
+                var source = await ImageSource.FromLFSObjectAsync(repo, lfs, decoder).ConfigureAwait(false);
                 var img = new Models.RevisionImageFile(file, source.Bitmap, source.Size);
                 Dispatcher.UIThread.Invoke(() => Image = img);
             });
