@@ -1,10 +1,9 @@
 ﻿using System;
 using System.Collections.Generic;
 using System.IO;
+using System.Threading.Tasks;
 
 using Avalonia.Collections;
-using Avalonia.Controls;
-
 using CommunityToolkit.Mvvm.ComponentModel;
 
 namespace SourceGit.ViewModels
@@ -83,35 +82,32 @@ namespace SourceGit.ViewModels
             }
         }
 
-        public void OpenOrInitRepository(string path, RepositoryNode parent, bool bMoveExistedNode)
+        public async Task<string> GetRepositoryRootAsync(string path)
         {
-            if (!Directory.Exists(path))
+            if (!Preferences.Instance.IsGitConfigured())
             {
-                if (File.Exists(path))
-                    path = Path.GetDirectoryName(path);
+                App.RaiseException(string.Empty, App.Text("NotConfigured"));
+                return null;
+            }
+
+            var root = path;
+            if (!Directory.Exists(root))
+            {
+                if (File.Exists(root))
+                    root = Path.GetDirectoryName(root);
                 else
-                    return;
+                    return null;
             }
 
-            var isBare = new Commands.IsBareRepository(path).Result();
-            var repoRoot = path;
-            if (!isBare)
-            {
-                var test = new Commands.QueryRepositoryRootPath(path).ReadToEnd();
-                if (!test.IsSuccess || string.IsNullOrEmpty(test.StdOut))
-                {
-                    InitRepository(path, parent, test.StdErr);
-                    return;
-                }
+            var isBare = await new Commands.IsBareRepository(root).GetResultAsync();
+            if (isBare)
+                return root;
 
-                repoRoot = test.StdOut.Trim();
-            }
+            var rs = await new Commands.QueryRepositoryRootPath(root).GetResultAsync();
+            if (!rs.IsSuccess || string.IsNullOrWhiteSpace(rs.StdOut))
+                return null;
 
-            var node = Preferences.Instance.FindOrAddNodeByRepositoryPath(repoRoot, parent, bMoveExistedNode);
-            Refresh();
-
-            var launcher = App.GetLauncher();
-            launcher?.OpenRepositoryInTab(node, launcher.ActivePage);
+            return rs.StdOut.Trim();
         }
 
         public void InitRepository(string path, RepositoryNode parent, string reason)
@@ -127,6 +123,13 @@ namespace SourceGit.ViewModels
                 activePage.Popup = new Init(activePage.Node.Id, path, parent, reason);
         }
 
+        public void AddRepository(string path, RepositoryNode parent, bool moveNode, bool open)
+        {
+            var node = Preferences.Instance.FindOrAddNodeByRepositoryPath(path, parent, moveNode);
+            if (open)
+                node.Open();
+        }
+
         public void Clone()
         {
             if (!Preferences.Instance.IsGitConfigured())
@@ -198,111 +201,6 @@ namespace SourceGit.ViewModels
             Refresh();
         }
 
-        public ContextMenu CreateContextMenu(RepositoryNode node)
-        {
-            var menu = new ContextMenu();
-
-            if (!node.IsRepository && node.SubNodes.Count > 0)
-            {
-                var openAll = new MenuItem();
-                openAll.Header = App.Text("Welcome.OpenAllInNode");
-                openAll.Icon = App.CreateMenuIcon("Icons.Folder.Open");
-                openAll.Click += (_, e) =>
-                {
-                    OpenAllInNode(App.GetLauncher(), node);
-                    e.Handled = true;
-                };
-
-                menu.Items.Add(openAll);
-                menu.Items.Add(new MenuItem() { Header = "-" });
-            }
-
-            if (node.IsRepository)
-            {
-                var open = new MenuItem();
-                open.Header = App.Text("Welcome.OpenOrInit");
-                open.Icon = App.CreateMenuIcon("Icons.Folder.Open");
-                open.Click += (_, e) =>
-                {
-                    App.GetLauncher()?.OpenRepositoryInTab(node, null);
-                    e.Handled = true;
-                };
-
-                var explore = new MenuItem();
-                explore.Header = App.Text("Repository.Explore");
-                explore.Icon = App.CreateMenuIcon("Icons.Explore");
-                explore.Click += (_, e) =>
-                {
-                    node.OpenInFileManager();
-                    e.Handled = true;
-                };
-
-                var terminal = new MenuItem();
-                terminal.Header = App.Text("Repository.Terminal");
-                terminal.Icon = App.CreateMenuIcon("Icons.Terminal");
-                terminal.Click += (_, e) =>
-                {
-                    node.OpenTerminal();
-                    e.Handled = true;
-                };
-
-                menu.Items.Add(open);
-                menu.Items.Add(new MenuItem() { Header = "-" });
-                menu.Items.Add(explore);
-                menu.Items.Add(terminal);
-                menu.Items.Add(new MenuItem() { Header = "-" });
-            }
-            else
-            {
-                var addSubFolder = new MenuItem();
-                addSubFolder.Header = App.Text("Welcome.AddSubFolder");
-                addSubFolder.Icon = App.CreateMenuIcon("Icons.Folder.Add");
-                addSubFolder.Click += (_, e) =>
-                {
-                    node.AddSubFolder();
-                    e.Handled = true;
-                };
-                menu.Items.Add(addSubFolder);
-            }
-
-            var edit = new MenuItem();
-            edit.Header = App.Text("Welcome.Edit");
-            edit.Icon = App.CreateMenuIcon("Icons.Edit");
-            edit.Click += (_, e) =>
-            {
-                node.Edit();
-                e.Handled = true;
-            };
-
-            var move = new MenuItem();
-            move.Header = App.Text("Welcome.Move");
-            move.Icon = App.CreateMenuIcon("Icons.MoveToAnotherGroup");
-            move.Click += (_, e) =>
-            {
-                var activePage = App.GetLauncher().ActivePage;
-                if (activePage != null && activePage.CanCreatePopup())
-                    activePage.Popup = new MoveRepositoryNode(node);
-
-                e.Handled = true;
-            };
-
-            var delete = new MenuItem();
-            delete.Header = App.Text("Welcome.Delete");
-            delete.Icon = App.CreateMenuIcon("Icons.Clear");
-            delete.Click += (_, e) =>
-            {
-                node.Delete();
-                e.Handled = true;
-            };
-
-            menu.Items.Add(edit);
-            menu.Items.Add(move);
-            menu.Items.Add(new MenuItem() { Header = "-" });
-            menu.Items.Add(delete);
-
-            return menu;
-        }
-
         private void ResetVisibility(RepositoryNode node)
         {
             node.IsVisible = true;
@@ -355,17 +253,6 @@ namespace SourceGit.ViewModels
             }
         }
 
-        private void OpenAllInNode(Launcher launcher, RepositoryNode node)
-        {
-            foreach (var subNode in node.SubNodes)
-            {
-                if (subNode.IsRepository)
-                    launcher.OpenRepositoryInTab(subNode, null);
-                else if (subNode.SubNodes.Count > 0)
-                    OpenAllInNode(launcher, subNode);
-            }
-        }
-
         private string _searchFilter = string.Empty;
     }
 }
