@@ -33,15 +33,46 @@ namespace SourceGit.Views
     {
         protected override Type StyleKeyOverride => typeof(ListBox);
 
-        protected override void OnKeyDown(KeyEventArgs e)
+        protected override async void OnKeyDown(KeyEventArgs e)
         {
-            if (SelectedItems is [ViewModels.ChangeTreeNode { IsFolder: true } node] && e.KeyModifiers == KeyModifiers.None)
+            if (SelectedItems is [ViewModels.ChangeTreeNode node])
             {
-                if ((node.IsExpanded && e.Key == Key.Left) || (!node.IsExpanded && e.Key == Key.Right))
+                if (((e.Key == Key.Left && node.IsExpanded) || (e.Key == Key.Right && !node.IsExpanded)) &&
+                    e.KeyModifiers == KeyModifiers.None)
                 {
                     this.FindAncestorOfType<ChangeCollectionView>()?.ToggleNodeIsExpanded(node);
                     e.Handled = true;
                 }
+                else if (e.Key == Key.C &&
+                    e.KeyModifiers.HasFlag(OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control))
+                {
+                    var path = node.FullPath;
+
+                    if (e.KeyModifiers.HasFlag(KeyModifiers.Shift))
+                    {
+                        do
+                        {
+                            var repoView = this.FindAncestorOfType<Repository>();
+                            if (repoView is { DataContext: ViewModels.Repository repo })
+                            {
+                                path = Native.OS.GetAbsPath(repo.FullPath, path);
+                                break;
+                            }
+
+                            var branchCompareView = this.FindAncestorOfType<BranchCompare>();
+                            if (branchCompareView is { DataContext: ViewModels.BranchCompare branchCompare })
+                            {
+                                path = branchCompare.GetAbsPath(path);
+                                break;
+                            }
+
+                            // NOTE: if there is another window uses ChangeCollectionView, add it here!
+                        } while (false);
+                    }
+
+                    await App.CopyTextAsync(path);
+                    e.Handled = true;
+                }
             }
 
             if (!e.Handled && e.Key != Key.Space && e.Key != Key.Enter)
@@ -87,15 +118,6 @@ namespace SourceGit.Views
             set => SetValue(ChangesProperty, value);
         }
 
-        public static readonly StyledProperty<bool> AutoSelectFirstChangeProperty =
-            AvaloniaProperty.Register<ChangeCollectionView, bool>(nameof(AutoSelectFirstChange));
-
-        public bool AutoSelectFirstChange
-        {
-            get => GetValue(AutoSelectFirstChangeProperty);
-            set => SetValue(AutoSelectFirstChangeProperty, value);
-        }
-
         public static readonly StyledProperty<List<Models.Change>> SelectedChangesProperty =
             AvaloniaProperty.Register<ChangeCollectionView, List<Models.Change>>(nameof(SelectedChanges));
 
@@ -121,7 +143,7 @@ namespace SourceGit.Views
 
         public void ToggleNodeIsExpanded(ViewModels.ChangeTreeNode node)
         {
-            if (Content is ViewModels.ChangeCollectionAsTree tree)
+            if (Content is ViewModels.ChangeCollectionAsTree tree && node.IsFolder)
             {
                 node.IsExpanded = !node.IsExpanded;
 
@@ -164,7 +186,10 @@ namespace SourceGit.Views
 
             var set = new HashSet<string>();
             foreach (var c in selected)
-                set.Add(c.Path);
+            {
+                if (!c.IsConflicted)
+                    set.Add(c.Path);
+            }
 
             if (Content is ViewModels.ChangeCollectionAsTree tree)
             {
@@ -365,24 +390,9 @@ namespace SourceGit.Views
                 MakeTreeRows(rows, tree.Tree);
                 tree.Rows.AddRange(rows);
 
-                if (!onlyViewModeChange && AutoSelectFirstChange)
+                if (selected.Count > 0)
                 {
-                    foreach (var row in tree.Rows)
-                    {
-                        if (row.Change != null)
-                        {
-                            tree.SelectedRows.Add(row);
-                            SetCurrentValue(SelectedChangesProperty, [row.Change]);
-                            break;
-                        }
-                    }
-                }
-                else if (selected.Count > 0)
-                {
-                    var sets = new HashSet<Models.Change>();
-                    foreach (var c in selected)
-                        sets.Add(c);
-
+                    var sets = new HashSet<Models.Change>(selected);
                     var nodes = new List<ViewModels.ChangeTreeNode>();
                     foreach (var row in tree.Rows)
                     {
@@ -399,16 +409,8 @@ namespace SourceGit.Views
             {
                 var grid = new ViewModels.ChangeCollectionAsGrid();
                 grid.Changes.AddRange(changes);
-
-                if (!onlyViewModeChange && AutoSelectFirstChange)
-                {
-                    grid.SelectedChanges.Add(changes[0]);
-                    SetCurrentValue(SelectedChangesProperty, [changes[0]]);
-                }
-                else if (selected.Count > 0)
-                {
+                if (selected.Count > 0)
                     grid.SelectedChanges.AddRange(selected);
-                }
 
                 Content = grid;
             }
@@ -416,16 +418,8 @@ namespace SourceGit.Views
             {
                 var list = new ViewModels.ChangeCollectionAsList();
                 list.Changes.AddRange(changes);
-
-                if (!onlyViewModeChange && AutoSelectFirstChange)
-                {
-                    list.SelectedChanges.Add(changes[0]);
-                    SetCurrentValue(SelectedChangesProperty, [changes[0]]);
-                }
-                else if (selected.Count > 0)
-                {
+                if (selected.Count > 0)
                     list.SelectedChanges.AddRange(selected);
-                }
 
                 Content = list;
             }
@@ -447,9 +441,7 @@ namespace SourceGit.Views
 
                 if (selected.Count > 0)
                 {
-                    var sets = new HashSet<Models.Change>();
-                    foreach (var c in selected)
-                        sets.Add(c);
+                    var sets = new HashSet<Models.Change>(selected);
 
                     var nodes = new List<ViewModels.ChangeTreeNode>();
                     foreach (var row in tree.Rows)
