@@ -1,4 +1,4 @@
-using System;
+﻿using System;
 
 using Avalonia;
 using Avalonia.Controls;
@@ -93,16 +93,6 @@ namespace SourceGit.Views
                 Activate();
         }
 
-        public bool HasKeyModifier(KeyModifiers modifier)
-        {
-            return _unhandledModifiers.HasFlag(modifier);
-        }
-
-        public void ClearKeyModifier()
-        {
-            _unhandledModifiers = KeyModifiers.None;
-        }
-
         protected override void OnOpened(EventArgs e)
         {
             base.OnOpened(e);
@@ -143,15 +133,11 @@ namespace SourceGit.Views
             }
         }
 
-        protected override void OnKeyDown(KeyEventArgs e)
+        protected override async void OnKeyDown(KeyEventArgs e)
         {
-            var vm = DataContext as ViewModels.Launcher;
-            if (vm == null)
+            if (DataContext is not ViewModels.Launcher vm)
                 return;
 
-            // We should clear all unhandled key modifiers.
-            _unhandledModifiers = KeyModifiers.None;
-
             // Check for AltGr (which is detected as Ctrl+Alt)
             bool isAltGr = e.KeyModifiers.HasFlag(KeyModifiers.Control) &&
                            e.KeyModifiers.HasFlag(KeyModifiers.Alt);
@@ -166,7 +152,7 @@ namespace SourceGit.Views
             // Ctrl+, opens preference dialog (macOS use hotkeys in system menu bar)
             if (!OperatingSystem.IsMacOS() && e is { KeyModifiers: KeyModifiers.Control, Key: Key.OemComma })
             {
-                App.ShowWindow(new Preferences(), true);
+                await App.ShowDialog(new Preferences());
                 e.Handled = true;
                 return;
             }
@@ -174,7 +160,7 @@ namespace SourceGit.Views
             // F1 opens preference dialog (macOS use hotkeys in system menu bar)
             if (!OperatingSystem.IsMacOS() && e.Key == Key.F1)
             {
-                App.ShowWindow(new Hotkeys(), true);
+                await App.ShowDialog(new Hotkeys());
                 return;
             }
 
@@ -208,7 +194,7 @@ namespace SourceGit.Views
                     return;
                 }
 
-                if (e.Key == Key.T)
+                if (e.Key == Key.T && !e.KeyModifiers.HasFlag(KeyModifiers.Shift))
                 {
                     vm.AddNewTab();
                     e.Handled = true;
@@ -243,39 +229,28 @@ namespace SourceGit.Views
 
                 if (vm.ActivePage.Data is ViewModels.Repository repo)
                 {
-                    if (e.Key == Key.D1 || e.Key == Key.NumPad1)
+                    switch (e.Key)
                     {
-                        repo.SelectedViewIndex = 0;
-                        e.Handled = true;
-                        return;
-                    }
-
-                    if (e.Key == Key.D2 || e.Key == Key.NumPad2)
-                    {
-                        repo.SelectedViewIndex = 1;
-                        e.Handled = true;
-                        return;
-                    }
-
-                    if (e.Key == Key.D3 || e.Key == Key.NumPad3)
-                    {
-                        repo.SelectedViewIndex = 2;
-                        e.Handled = true;
-                        return;
-                    }
-
-                    if (e.Key == Key.F)
-                    {
-                        repo.IsSearching = true;
-                        e.Handled = true;
-                        return;
-                    }
-
-                    if (e.Key == Key.H && e.KeyModifiers.HasFlag(KeyModifiers.Shift))
-                    {
-                        repo.IsSearching = false;
-                        e.Handled = true;
-                        return;
+                        case Key.D1 or Key.NumPad1:
+                            repo.SelectedViewIndex = 0;
+                            e.Handled = true;
+                            return;
+                        case Key.D2 or Key.NumPad2:
+                            repo.SelectedViewIndex = 1;
+                            e.Handled = true;
+                            return;
+                        case Key.D3 or Key.NumPad3:
+                            repo.SelectedViewIndex = 2;
+                            e.Handled = true;
+                            return;
+                        case Key.F:
+                            repo.IsSearching = true;
+                            e.Handled = true;
+                            return;
+                        case Key.H when e.KeyModifiers.HasFlag(KeyModifiers.Shift):
+                            repo.IsSearching = false;
+                            e.Handled = true;
+                            return;
                     }
                 }
                 else
@@ -313,27 +288,6 @@ namespace SourceGit.Views
             }
 
             base.OnKeyDown(e);
-
-            // Record unhandled key modifiers.
-            if (!e.Handled)
-            {
-                _unhandledModifiers = e.KeyModifiers;
-
-                if (!_unhandledModifiers.HasFlag(KeyModifiers.Alt) && e.Key is Key.LeftAlt or Key.RightAlt)
-                    _unhandledModifiers |= KeyModifiers.Alt;
-
-                if (!_unhandledModifiers.HasFlag(KeyModifiers.Control) && e.Key is Key.LeftCtrl or Key.RightCtrl)
-                    _unhandledModifiers |= KeyModifiers.Control;
-
-                if (!_unhandledModifiers.HasFlag(KeyModifiers.Shift) && e.Key is Key.LeftShift or Key.RightShift)
-                    _unhandledModifiers |= KeyModifiers.Shift;
-            }
-        }
-
-        protected override void OnKeyUp(KeyEventArgs e)
-        {
-            base.OnKeyUp(e);
-            _unhandledModifiers = KeyModifiers.None;
         }
 
         protected override void OnClosing(WindowClosingEventArgs e)
@@ -361,8 +315,41 @@ namespace SourceGit.Views
         {
             if (sender is Button btn && DataContext is ViewModels.Launcher launcher)
             {
-                var menu = launcher.CreateContextForWorkspace();
-                menu?.Open(btn);
+                var pref = ViewModels.Preferences.Instance;
+                var menu = new ContextMenu();
+
+                for (var i = 0; i < pref.Workspaces.Count; i++)
+                {
+                    var workspace = pref.Workspaces[i];
+
+                    var icon = App.CreateMenuIcon(workspace.IsActive ? "Icons.Check" : "Icons.Workspace");
+                    icon.Fill = workspace.Brush;
+
+                    var item = new MenuItem();
+                    item.Header = workspace.Name;
+                    item.Icon = icon;
+                    item.Click += (_, e) =>
+                    {
+                        if (!workspace.IsActive)
+                            launcher.SwitchWorkspace(workspace);
+
+                        e.Handled = true;
+                    };
+
+                    menu.Items.Add(item);
+                }
+
+                menu.Items.Add(new MenuItem() { Header = "-" });
+
+                var configure = new MenuItem();
+                configure.Header = App.Text("Workspace.Configure");
+                configure.Click += async (_, e) =>
+                {
+                    await App.ShowDialog(new ViewModels.ConfigureWorkspace());
+                    e.Handled = true;
+                };
+                menu.Items.Add(configure);
+                menu.Open(btn);
             }
 
             e.Handled = true;
@@ -375,7 +362,6 @@ namespace SourceGit.Views
             e.Handled = true;
         }
 
-        private KeyModifiers _unhandledModifiers = KeyModifiers.None;
         private WindowState _lastWindowState = WindowState.Normal;
     }
 }
