@@ -1,8 +1,10 @@
 using System;
+
 using Avalonia.Controls;
 using Avalonia.Controls.Presenters;
 using Avalonia.Input;
 using Avalonia.Interactivity;
+using Avalonia.LogicalTree;
 
 namespace SourceGit.Views
 {
@@ -13,6 +15,33 @@ namespace SourceGit.Views
             InitializeComponent();
         }
 
+        private void OnPopupSureByHotKey(object sender, RoutedEventArgs e)
+        {
+            var children = this.GetLogicalDescendants();
+            foreach (var child in children)
+            {
+                if (child is TextBox { IsFocused: true, Tag: StealHotKey steal } textBox &&
+                    steal is { Key: Key.Enter, KeyModifiers: KeyModifiers.None })
+                {
+                    var fake = new KeyEventArgs()
+                    {
+                        RoutedEvent = KeyDownEvent,
+                        Route = RoutingStrategies.Direct,
+                        Source = textBox,
+                        Key = Key.Enter,
+                        KeyModifiers = KeyModifiers.None,
+                        PhysicalKey = PhysicalKey.Enter,
+                    };
+
+                    textBox.RaiseEvent(fake);
+                    e.Handled = false;
+                    return;
+                }
+            }
+
+            OnPopupSure(sender, e);
+        }
+
         private void OnPopupSure(object _, RoutedEventArgs e)
         {
             if (DataContext is ViewModels.LauncherPage page)
@@ -34,10 +63,10 @@ namespace SourceGit.Views
             OnPopupCancel(sender, e);
         }
 
-        private void OnCopyNotification(object sender, RoutedEventArgs e)
+        private async void OnCopyNotification(object sender, RoutedEventArgs e)
         {
             if (sender is Button { DataContext: Models.Notification notice })
-                App.CopyText(notice.Message);
+                await App.CopyTextAsync(notice.Message);
 
             e.Handled = true;
         }
@@ -56,28 +85,9 @@ namespace SourceGit.Views
             if (sender is ContentPresenter presenter)
             {
                 if (presenter.DataContext is not ViewModels.Popup)
-                {
                     presenter.Content = null;
-                    return;
-                }
-
-                var dataTypeName = presenter.DataContext.GetType().FullName;
-                if (string.IsNullOrEmpty(dataTypeName))
-                {
-                    presenter.Content = null;
-                    return;
-                }
-
-                var viewTypeName = dataTypeName.Replace(".ViewModels.", ".Views.");
-                var viewType = Type.GetType(viewTypeName);
-                if (viewType == null)
-                {
-                    presenter.Content = null;
-                    return;
-                }
-
-                var view = Activator.CreateInstance(viewType);
-                presenter.Content = view;
+                else
+                    presenter.Content = App.CreateViewForViewModel(presenter.DataContext);
             }
         }
     }
